#!/bin/bash

# Path the hmg binary
HMG_EXECUTABLE=/opt/fortanix/bin/hmg

set -e -o pipefail

# systemd prevents restart on specified exit codes, 1 in this case, but
# for a forking service, the main process as determined by systemd is
# the process forked from this script, which must return the exit code
fork_exit(){
    (exit 1 &)
    exit 1
}

# Check all parameters and output errors for all before exiting
EXIT_FLAG=0

if [ -z $PKCS11_LIB_PATH ];then
    echo "ERROR: PKCS11_LIB_PATH is unset. Please configure in /etc/default/ftx-hmg"
    EXIT_FLAG=1
fi

if [ -z $CERT_FILE ] || ! [ -f $CERT_FILE ];then
    CERT_DIR=$(dirname $CERT_FILE 2>/dev/null || echo "/path/to/cert/dir")
    echo "ERROR: A p12 certificate is required to start. Please configure in /etc/default/ftx-hmg"
    echo "  A self signed cert can be generated using:"
    echo "    openssl req -x509 -newkey rsa:4096 -keyout $CERT_DIR/key.pem -out $CERT_DIR/cert.pem -days 365 -nodes"
    echo "    openssl pkcs12 -export -out $CERT_DIR/cert.p12 -inkey $CERT_DIR/key.pem -in $CERT_DIR/cert.pem"
    EXIT_FLAG=1
fi

if ! [ -f $HMG_EXECUTABLE ];then
    echo "ERROR: Cannot locate the HMG binary."
    echo "  Something went wrong during the installation or files have been moved unexpectedly."
    EXIT_FLAG=1
fi

if [[ $EXIT_FLAG -ne 0 ]];then
    fork_exit
fi

# Spawn the hmg in the background and exit successfully
($HMG_EXECUTABLE --module ${PKCS11_LIB_PATH} --cert ${CERT_FILE} --port ${HMG_LISTEN_PORT} &)

exit 0
